=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-06-02 13:56:17 +0000
+++ drizzled/drizzled.cc	2011-06-02 15:09:32 +0000
@@ -2208,9 +2208,6 @@
     default_storage_engine_str= vm["default-storage-engine"].as<string>().c_str();
   }
 
-  /* Skip unknown options so that they may be processed later by plugins */
-  my_getopt_skip_unknown= true;
-
 
 #if defined(HAVE_BROKEN_REALPATH)
   internal::my_use_symdir=0;

=== modified file 'drizzled/option.cc'
--- drizzled/option.cc	2011-06-02 14:13:35 +0000
+++ drizzled/option.cc	2011-06-02 15:09:32 +0000
@@ -35,14 +35,7 @@
 
 namespace drizzled {
 
-  typedef void (*init_func_p)(const struct option *option, char **variable, int64_t value);
-
-  void default_reporter(enum loglevel level, const char *format, ...);
-  my_error_reporter my_getopt_error_reporter= &default_reporter;
-
-  bool my_getopt_skip_unknown= false;
-
-  void default_reporter(enum loglevel level, const char *format, ...)
+  static void default_reporter(enum loglevel level, const char *format, ...)
   {
     va_list args;
     va_start(args, format);
@@ -82,22 +75,21 @@
 Returns "fixed" value.
    */
 
-  int64_t getopt_ll_limit_value(int64_t num, const struct option *optp,
-      bool *fix)
+  int64_t getopt_ll_limit_value(int64_t num, const option& optp, bool *fix)
   {
     int64_t old= num;
     bool adjusted= false;
     char buf1[255], buf2[255];
-    uint64_t block_size= optp->block_size ? optp->block_size : 1;
+    uint64_t block_size= optp.block_size ? optp.block_size : 1;
 
-    if (num > 0 && ((uint64_t) num > (uint64_t) optp->max_value) &&
-        optp->max_value) /* if max value is not set -> no upper limit */
+    if (num > 0 && ((uint64_t) num > (uint64_t) optp.max_value) &&
+        optp.max_value) /* if max value is not set -> no upper limit */
     {
-      num= (uint64_t) optp->max_value;
+      num= (uint64_t) optp.max_value;
       adjusted= true;
     }
 
-    switch ((optp->var_type & GET_TYPE_MASK)) {
+    switch ((optp.var_type & GET_TYPE_MASK)) {
       case GET_INT:
         if (num > (int64_t) INT_MAX)
         {
@@ -113,25 +105,25 @@
         }
         break;
       default:
-        assert((optp->var_type & GET_TYPE_MASK) == GET_LL);
+        assert((optp.var_type & GET_TYPE_MASK) == GET_LL);
         break;
     }
 
-    num= ((num - optp->sub_size) / block_size);
+    num= ((num - optp.sub_size) / block_size);
     num= (int64_t) (num * block_size);
 
-    if (num < optp->min_value)
+    if (num < optp.min_value)
     {
-      num= optp->min_value;
+      num= optp.min_value;
       adjusted= true;
     }
 
     if (fix)
       *fix= adjusted;
     else if (adjusted)
-      my_getopt_error_reporter(WARNING_LEVEL,
+      default_reporter(WARNING_LEVEL,
           "option '%s': signed value %s adjusted to %s",
-          optp->name, internal::llstr(old, buf1), internal::llstr(num, buf2));
+          optp.name, internal::llstr(old, buf1), internal::llstr(num, buf2));
     return num;
   }
 
@@ -142,21 +134,20 @@
 values.
    */
 
-  uint64_t getopt_ull_limit_value(uint64_t num, const struct option *optp,
-      bool *fix)
+  uint64_t getopt_ull_limit_value(uint64_t num, const option& optp, bool *fix)
   {
     bool adjusted= false;
     uint64_t old= num;
     char buf1[255], buf2[255];
 
-    if ((uint64_t) num > (uint64_t) optp->max_value &&
-        optp->max_value) /* if max value is not set -> no upper limit */
+    if ((uint64_t) num > (uint64_t) optp.max_value &&
+        optp.max_value) /* if max value is not set -> no upper limit */
     {
-      num= (uint64_t) optp->max_value;
+      num= (uint64_t) optp.max_value;
       adjusted= true;
     }
 
-    switch (optp->var_type & GET_TYPE_MASK)
+    switch (optp.var_type & GET_TYPE_MASK)
     {
       case GET_UINT:
         if (num > UINT_MAX)
@@ -181,26 +172,26 @@
         }
         break;
       default:
-        assert((optp->var_type & GET_TYPE_MASK) == GET_ULL || (optp->var_type & GET_TYPE_MASK) == GET_UINT64);
-    }
-
-    if (optp->block_size > 1)
-    {
-      num/= optp->block_size;
-      num*= optp->block_size;
-    }
-
-    if (num < (uint64_t) optp->min_value)
-    {
-      num= (uint64_t) optp->min_value;
+        assert((optp.var_type & GET_TYPE_MASK) == GET_ULL || (optp.var_type & GET_TYPE_MASK) == GET_UINT64);
+    }
+
+    if (optp.block_size > 1)
+    {
+      num/= optp.block_size;
+      num*= optp.block_size;
+    }
+
+    if (num < (uint64_t) optp.min_value)
+    {
+      num= (uint64_t) optp.min_value;
       adjusted= true;
     }
 
     if (fix)
       *fix= adjusted;
     else if (adjusted)
-      my_getopt_error_reporter(WARNING_LEVEL, "option '%s': unsigned value %s adjusted to %s",
-          optp->name, internal::ullstr(old, buf1), internal::ullstr(num, buf2));
+      default_reporter(WARNING_LEVEL, "option '%s': unsigned value %s adjusted to %s",
+          optp.name, internal::ullstr(old, buf1), internal::ullstr(num, buf2));
 
     return num;
   }
@@ -212,7 +203,7 @@
 Print help for all options and variables.
    */
 
-  void my_print_help(const struct option *options)
+  void my_print_help(const option* options)
   {
     uint32_t col, name_space= 22, comment_space= 57;
     const char *line_end;

=== modified file 'drizzled/option.h'
--- drizzled/option.h	2011-06-02 14:13:35 +0000
+++ drizzled/option.h	2011-06-02 15:09:32 +0000
@@ -66,18 +66,13 @@
 typedef void (* my_error_reporter) (enum loglevel level, const char *format, ... );
 typedef char ** (*getopt_get_addr_func)(const char *, uint32_t, const struct option *);
 
-extern bool my_getopt_skip_unknown;
-
-extern int handle_options (int *argc, char ***argv,
-			   const struct option *longopts, my_get_one_option);
+extern int handle_options (int *argc, char ***argv, const option*, my_get_one_option);
 extern void my_cleanup_options(const struct option *options);
 extern void my_print_help(const struct option *options);
 extern void my_print_variables(const struct option *options);
 
-uint64_t getopt_ull_limit_value(uint64_t num, const struct option *optp,
-                                 bool *fix);
-int64_t getopt_ll_limit_value(int64_t, const struct option *,
-                               bool *fix);
+uint64_t getopt_ull_limit_value(uint64_t num, const option&, bool* fix);
+int64_t getopt_ll_limit_value(int64_t, const option&, bool* fix);
 bool getopt_compare_strings(const char *s, const char *t, uint32_t length);
 
 } /* namespace drizzled */

=== modified file 'drizzled/sys_var.cc'
--- drizzled/sys_var.cc	2011-06-02 13:37:57 +0000
+++ drizzled/sys_var.cc	2011-06-02 15:09:32 +0000
@@ -114,8 +114,7 @@
 static void fix_max_join_size(Session *session, sql_var_t type);
 static void fix_session_mem_root(Session *session, sql_var_t type);
 static void fix_server_id(Session *session, sql_var_t type);
-bool throw_bounds_warning(Session *session, bool fixed, bool unsignd,
-                          const std::string &name, int64_t val);
+void throw_bounds_warning(Session *session, bool fixed, bool unsignd, const std::string &name, int64_t val);
 static unsigned char *get_error_count(Session *session);
 static unsigned char *get_warning_count(Session *session);
 static unsigned char *get_tmpdir(Session *session);
@@ -437,43 +436,37 @@
 }
 
 
-bool throw_bounds_warning(Session *session, bool fixed, bool unsignd,
-                          const std::string &name, int64_t val)
+void throw_bounds_warning(Session *session, bool fixed, bool unsignd, const std::string &name, int64_t val)
 {
-  if (fixed)
-  {
-    char buf[DECIMAL_LONGLONG_DIGITS];
-
-    if (unsignd)
-      internal::ullstr((uint64_t) val, buf);
-    else
-      internal::llstr(val, buf);
-
-    push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
-                        ER_TRUNCATED_WRONG_VALUE,
-                        ER(ER_TRUNCATED_WRONG_VALUE), name.c_str(), buf);
-  }
-  return false;
+  if (not fixed)
+    return;
+  char buf[DECIMAL_LONGLONG_DIGITS];
+
+  if (unsignd)
+    internal::ullstr((uint64_t) val, buf);
+  else
+    internal::llstr(val, buf);
+
+  push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
+    ER_TRUNCATED_WRONG_VALUE, ER(ER_TRUNCATED_WRONG_VALUE), name.c_str(), buf);
 }
 
-uint64_t fix_unsigned(Session *session, uint64_t num,
-                              const struct option *option_limits)
+uint64_t fix_unsigned(Session *session, uint64_t num, const option& option_limits)
 {
   bool fixed= false;
   uint64_t out= getopt_ull_limit_value(num, option_limits, &fixed);
 
-  throw_bounds_warning(session, fixed, true, option_limits->name, (int64_t) num);
+  throw_bounds_warning(session, fixed, true, option_limits.name, (int64_t) num);
   return out;
 }
 
 
-static size_t fix_size_t(Session *session, size_t num,
-                           const struct option *option_limits)
+static size_t fix_size_t(Session *session, size_t num, const option& option_limits)
 {
   bool fixed= false;
   size_t out= (size_t)getopt_ull_limit_value(num, option_limits, &fixed);
 
-  throw_bounds_warning(session, fixed, true, option_limits->name, (int64_t) num);
+  throw_bounds_warning(session, fixed, true, option_limits.name, (int64_t) num);
   return out;
 }
 
@@ -490,8 +483,8 @@
 
   if (option_limits)
   {
-    uint32_t newvalue= (uint32_t) fix_unsigned(session, tmp, option_limits);
-    if(static_cast<uint64_t>(newvalue) == tmp)
+    uint32_t newvalue= (uint32_t) fix_unsigned(session, tmp, *option_limits);
+    if (static_cast<uint64_t>(newvalue) == tmp)
       *value= newvalue;
   }
   else
@@ -507,8 +500,7 @@
 {
   bool not_used;
   boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
-  *value= (uint32_t)getopt_ull_limit_value((uint32_t) option_limits->def_value,
-                                           option_limits, &not_used);
+  *value= (uint32_t)getopt_ull_limit_value((uint32_t) option_limits->def_value, *option_limits, &not_used);
 }
 
 
@@ -519,8 +511,8 @@
 
   if (option_limits)
   {
-    uint64_t newvalue= fix_unsigned(session, tmp, option_limits);
-    if(newvalue==tmp)
+    uint64_t newvalue= fix_unsigned(session, tmp, *option_limits);
+    if (newvalue==tmp)
       *value= newvalue;
   }
   else
@@ -542,8 +534,7 @@
   {
     bool not_used;
     boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
-    *value= getopt_ull_limit_value((uint64_t) option_limits->def_value,
-                                   option_limits, &not_used);
+    *value= getopt_ull_limit_value((uint64_t) option_limits->def_value, *option_limits, &not_used);
   }
 }
 
@@ -555,7 +546,7 @@
   boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
 
   if (option_limits)
-    *value= fix_size_t(session, tmp, option_limits);
+    *value= fix_size_t(session, tmp, *option_limits);
   else
     *value= tmp;
 
@@ -567,8 +558,7 @@
 {
   bool not_used;
   boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
-  *value= (size_t)getopt_ull_limit_value((size_t) option_limits->def_value,
-                                         option_limits, &not_used);
+  *value= (size_t)getopt_ull_limit_value((size_t) option_limits->def_value, *option_limits, &not_used);
 }
 
 bool sys_var_bool_ptr::check(Session *session, set_var *var)
@@ -610,7 +600,7 @@
   }
 
   if (option_limits)
-    tmp= (uint32_t) fix_unsigned(session, tmp, option_limits);
+    tmp= (uint32_t) fix_unsigned(session, tmp, *option_limits);
   else if (tmp > UINT32_MAX)
   {
     tmp= UINT32_MAX;
@@ -633,8 +623,7 @@
      bool not_used;
      /* We will not come here if option_limits is not set */
      global_system_variables.*offset=
-       (uint32_t) getopt_ull_limit_value((uint32_t) option_limits->def_value,
-                                      option_limits, &not_used);
+       (uint32_t) getopt_ull_limit_value((uint32_t) option_limits->def_value, *option_limits, &not_used);
    }
    else
      session->variables.*offset= global_system_variables.*offset;
@@ -660,7 +649,7 @@
     tmp= max_system_variables.*offset;
 
   if (option_limits)
-    tmp= (ha_rows) fix_unsigned(session, tmp, option_limits);
+    tmp= (ha_rows) fix_unsigned(session, tmp, *option_limits);
   if (var->type == OPT_GLOBAL)
   {
     /* Lock is needed to make things safe on 32 bit systems */
@@ -684,8 +673,7 @@
     /* We will not come here if option_limits is not set */
     boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset=
-      (ha_rows) getopt_ull_limit_value((ha_rows) option_limits->def_value,
-                                       option_limits, &not_used);
+      (ha_rows) getopt_ull_limit_value((ha_rows) option_limits->def_value, *option_limits, &not_used);
   }
   else
   {
@@ -720,7 +708,7 @@
   }
 
   if (option_limits)
-    tmp= fix_unsigned(session, tmp, option_limits);
+    tmp= fix_unsigned(session, tmp, *option_limits);
   if (var->type == OPT_GLOBAL)
   {
     /* Lock is needed to make things safe on 32 bit systems */
@@ -743,8 +731,7 @@
     bool not_used;
     boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset=
-      getopt_ull_limit_value((uint64_t) option_limits->def_value,
-                             option_limits, &not_used);
+      getopt_ull_limit_value((uint64_t) option_limits->def_value, *option_limits, &not_used);
   }
   else
   {
@@ -776,7 +763,7 @@
     tmp= max_system_variables.*offset;
 
   if (option_limits)
-    tmp= fix_size_t(session, tmp, option_limits);
+    tmp= fix_size_t(session, tmp, *option_limits);
   if (var->type == OPT_GLOBAL)
   {
     /* Lock is needed to make things safe on 32 bit systems */
@@ -799,8 +786,7 @@
     bool not_used;
     boost::mutex::scoped_lock scopedLock(session->catalog().systemVariableLock());
     global_system_variables.*offset=
-      (size_t)getopt_ull_limit_value((size_t) option_limits->def_value,
-                                     option_limits, &not_used);
+      (size_t)getopt_ull_limit_value((size_t) option_limits->def_value, *option_limits, &not_used);
   }
   else
   {

=== modified file 'drizzled/sys_var.h'
--- drizzled/sys_var.h	2011-04-20 22:18:30 +0000
+++ drizzled/sys_var.h	2011-06-02 15:09:32 +0000
@@ -67,7 +67,7 @@
 extern const char *opt_scheduler;
 extern size_t transaction_message_threshold;
 
-uint64_t fix_unsigned(Session *, uint64_t, const struct option *);
+uint64_t fix_unsigned(Session*, uint64_t, const option&);
 
 DRIZZLED_API const std::string &getServerHostname();
 int sys_var_init();

